%global         product_id dogtag-jss

%global major_version %%(echo %{version} | cut -d. -f1)
%global minor_version %%(echo %{version} | cut -d. -f2)
%global update_version %%(echo %{version} | cut -d. -f3)

%global java_devel java-17-devel
%global java_headless java-17-headless
%global java_home %{_jvmdir}/jre-17

%global slf4j_ver 1.7.36
%global __provides_exclude ^osgi\\(slf4j.
%global __requires_exclude ^osgi\\(slf4j.

%bcond_with javadoc
%bcond_with tests

Summary:        Java Security Services (JSS)
Name:           jss
Version:        5.5.0
Release:        1%{?dist}
License:        MPLv1.1 or GPLv2+ or LGPLv2+
URL:            https://github.com/dogtagpki/jss
Source0:        https://github.com/dogtagpki/jss/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/qos-ch/slf4j/archive/v_%{slf4j_ver}/slf4j-v_%{slf4j_ver}.tar.gz

BuildRequires:  make cmake >= 3.14 gcc-c++ zip unzip
BuildRequires:  nss-devel >= 3.66 nss-tools >= 3.66
BuildRequires:  %{java_devel} jpackage-utils apache-commons-lang3
BuildRequires:  maven >= 3.9.9 maven-buildrequires >= 3.9.9
# for using mvn macro
BuildRequires:  javapackages-common

ExclusiveArch:  %{java_arches}

%description
Java Security Services (JSS) is a java native interface which provides a bridge
for java-based applications to use native Network Security Services (NSS).
This only works with gcj. Other JREs require that JCE providers be signed.

%package -n %{product_id}
Summary:        Java Security Services (JSS)
Requires:       nss >= 3.66
Requires:       %{java_headless} jpackage-utils apache-commons-lang3
Obsoletes:      jss < %{version}-%{release}
Obsoletes:      slf4j < %{slf4j_ver} slf4j-jdk14 < %{slf4j_ver} jcl-over-slf4j < %{slf4j_ver}
Obsoletes:      maven < 3.9.9 maven-lib < 3.9.9 maven-openjdk17 < 3.9.9
Obsoletes:      maven-resolver <= 1.7.3 maven-wagon <= 3.5.1
Provides:       jss = %{version}-%{release}
Provides:       jss = %{major_version}.%{minor_version}
Provides:       %{product_id} = %{major_version}.%{minor_version}

%description -n %{product_id}
Java Security Services (JSS) is a java native interface which provides a bridge
for java-based applications to use native Network Security Services (NSS).
This only works with gcj. Other JREs require that JCE providers be signed.

%if %{with javadoc}
%package -n %{product_id}-javadoc
Summary:        Java Security Services (JSS) Javadocs
Obsoletes:      jss-javadoc < %{version}-%{release}
Provides:       jss-javadoc = %{version}-%{release}
Provides:       jss-javadoc = %{major_version}.%{minor_version}
Provides:       %{product_id}-javadoc = %{major_version}.%{minor_version}

%description -n %{product_id}-javadoc
This package contains the API documentation for JSS.
%endif

%prep
%autosetup -n jss-%{version}
tar -zxf %SOURCE1

# disable slf4j modules
pushd slf4j-v_%{slf4j_ver}
%pom_disable_module slf4j-log4j12
%pom_disable_module slf4j-reload4j
%pom_disable_module slf4j-jcl
%pom_disable_module slf4j-android
%pom_disable_module slf4j-ext
%pom_disable_module jul-to-slf4j
%pom_disable_module integration
%pom_disable_module slf4j-site
%pom_disable_module slf4j-migrator
%pom_disable_module jcl-over-slf4j
%pom_disable_module log4j-over-slf4j
%pom_disable_module osgi-over-slf4j

sed -i s/tasks/target/ slf4j-api/pom.xml
popd

%build
export JAVA_HOME=%{java_home}
export BUILD_OPT=1
export CFLAGS="-g %{optflags}"

# build slf4j
pushd slf4j-v_%{slf4j_ver}
/usr/bin/mvn -X -o clean package -Dgpg.skip=true -Dmaven.test.skip=true -Dmaven.javadoc.skip=true -Dmaven.repo.local=/usr/lib/maven/repository/ -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8 -Drequired.jdk.version=8
popd

mkdir jars
cp -ar slf4j-v_%{slf4j_ver}/slf4j-api/target/slf4j-api-%{slf4j_ver}.jar jars/slf4j-api.jar
cp -ar slf4j-v_%{slf4j_ver}/slf4j-jdk14/target/slf4j-jdk14-%{slf4j_ver}.jar jars/slf4j-jdk14.jar
sed -i.bak '/macro(jss_config_java)/a \    set(Java_JAR_PATHS "%{_builddir}/%{name}-%{version}/jars")' cmake/JSSConfig.cmake

modutil -dbdir /etc/pki/nssdb -chkfips true | grep -q enabled && export FIPS_ENABLED=1

./build.sh \
    %{?_verbose:-v} \
    --work-dir=%{_vpath_builddir} \
    --prefix-dir=%{_prefix} \
    --include-dir=%{_includedir} \
    --lib-dir=%{_libdir} \
    --sysconf-dir=%{_sysconfdir} \
    --share-dir=%{_datadir} \
    --cmake=%{__cmake} \
    --java-home=%{java_home} \
    --jni-dir=%{_jnidir} \
    --version=%{version} \
    %{!?with_javadoc:--without-javadoc} \
    %{!?with_tests:--without-tests} \
    dist

%install
./build.sh \
    %{?_verbose:-v} \
    --work-dir=%{_vpath_builddir} \
    --install-dir=%{buildroot} \
    install

mkdir -p %{buildroot}%{_datadir}/java/slf4j
install -pm 0644 -D slf4j-v_%{slf4j_ver}/slf4j-api/target/slf4j-api-%{slf4j_ver}.jar \
	%{buildroot}%{_datadir}/java/slf4j/slf4j-api.jar
ln -sf slf4j-api.jar %{buildroot}%{_datadir}/java/slf4j/api.jar
install -pm 0644 -D slf4j-v_%{slf4j_ver}/slf4j-nop/target/slf4j-nop-%{slf4j_ver}.jar \
	%{buildroot}%{_datadir}/java/slf4j/slf4j-nop.jar
ln -sf slf4j-nop.jar %{buildroot}%{_datadir}/java/slf4j/nop.jar
install -pm 0644 -D slf4j-v_%{slf4j_ver}/slf4j-simple/target/slf4j-simple-%{slf4j_ver}.jar \
	%{buildroot}%{_datadir}/java/slf4j/slf4j-simple.jar
ln -sf slf4j-simple.jar %{buildroot}%{_datadir}/java/slf4j/simple.jar
install -pm 0644 -D slf4j-v_%{slf4j_ver}/slf4j-jdk14/target/slf4j-jdk14-%{slf4j_ver}.jar \
	%{buildroot}%{_datadir}/java/slf4j/slf4j-jdk14.jar
ln -sf slf4j-jdk14.jar %{buildroot}%{_datadir}/java/slf4j/jdk14.jar

%files -n %{product_id}
%defattr(-,root,root,-)
%license MPL-1.1.txt gpl.txt lgpl.txt symkey/LICENSE
%doc jss.html
%{_libdir}/*
%{_jnidir}/*
%{_datadir}/java/slf4j/*

%if %{with javadoc}
%files -n %{product_id}-javadoc
%defattr(-,root,root,-)
%{_javadocdir}/jss/
%endif

%changelog
* Tue Jan 21 2025 Xiaojie Chen <jackxjchen@tencent.com> - 5.5.0-1
- [Type] other
- [DESC] Upgrade to upstream version 5.5.0
- Disable tests

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.4.1-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.4.1-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.4.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 14 2023 Miaojun Dong <zoedong@tencent.com> - 5.4.1-2
- Fix macro defination

* Thu Jul 13 2023 Miaojun Dong <zoedong@tencent.com> - 5.4.1-1
- Bump version to 5.4.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 25 2023 Miaojun Dong <zoedong@tencent.com> - 5.3.0-1
- update version to 5.3.0

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.2.0-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 16 2023 Xin Cheng <denisecheng@tencent.com> - 5.2.0-1
- Init package
